/* $Id: bs_area.c,v 1.2 2006/01/28 16:46:10 cegger Exp $
***************************************************************************

   X server for LibGGI - Graphics acceleration for backingstore functions

   Copyright (C) 1997      Michael Krause       [rawstyle@ms.demo.org]
   Copyright (C) 1998-1999 Marcus Sundberg      [marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

***************************************************************************
*/


#include "screen.h"


/*
 * xggiSaveRestoreAreas - accelerated replacement for cfbSaveAreas & cfbRestoreAreas
 *
 */
void xggiSaveRestoreAreas(PixmapPtr pPixmap,	/* Backing pixmap */
			RegionPtr prgnSave,	/* Region to save (pixmap/screen-relative) */
			int xorg,		/* X origin of region */
			int yorg,		/* Y origin of region */
			WindowPtr pWin)
{
	int scr;
	BoxPtr pbox;
	int nboxes;

	scr = xggiGetScreenIdx(pPixmap->drawable.pScreen);

	if (!(PIXMAP_HAS_MASTER_VISUAL_BPP(pPixmap, scr))) {
		ErrorF("BUG in xggiSaveRestoreAreas: pixmap depth %i != visual depth %i\n",
			pPixmap->drawable.bitsPerPixel,
			MASTER_VISUAL_BPP(scr));
	}	/* if */

	pbox = REGION_RECTS(prgnSave);
	nboxes = REGION_NUM_RECTS(prgnSave);

	DBUF_PROLOGUE(scr);
	while(nboxes--) {
		ggiCopyBox(MASTER_VISUAL_VIS(scr),
			pbox->x1 + xorg, pbox->y1 + yorg,  
			pbox->x2 - pbox->x1, pbox->y2 - pbox->y1,
			pPixmap->drawable.x + pbox->x1,
			pPixmap->drawable.y + pbox->y1);
		pbox++;
	}	/* while */
	DBUF_EPILOGUE(scr);
	return;

}	/* xggiSaveAreas */
